@@ -1,6 +1,6 @@
 import asyncio
 import gc
-from typing import AsyncIterator, Callable, Iterator, NoReturn
+from typing import AsyncIterator, Callable, Iterator, NoReturn, Type
 from unittest import mock
 
 import pytest
@@ -476,7 +476,10 @@ async def test_cleanup_ctx_cleanup_after_exception() -> None:
     assert ctx_state == "CLEAN"
 
 
-async def test_cleanup_ctx_exception_on_cleanup_multiple() -> None:
+@pytest.mark.parametrize("exc_cls", (Exception, asyncio.CancelledError))
+async def test_cleanup_ctx_exception_on_cleanup_multiple(
+    exc_cls: Type[BaseException],
+) -> None:
     app = web.Application()
     out = []
 
@@ -488,7 +491,7 @@ async def test_cleanup_ctx_exception_on_cleanup_multiple() -> None:
             yield None
             out.append("post_" + str(num))
             if fail:
-                raise Exception("fail_" + str(num))
+                raise exc_cls("fail_" + str(num))
 
         return inner
 
